/******/ (() => { // webpackBootstrap
/******/ 	"use strict";
/******/ 	var __webpack_modules__ = ({

/***/ "./src/components/Container.tsx":
/*!**************************************!*\
  !*** ./src/components/Container.tsx ***!
  \**************************************/
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
const react_1 = __importDefault(__webpack_require__(/*! react */ "react"));
const Notification_1 = __importDefault(__webpack_require__(/*! src/components/Notification */ "./src/components/Notification.tsx"));
__webpack_require__(/*! src/scss/notification.scss */ "./src/scss/notification.scss");
const store_1 = __importDefault(__webpack_require__(/*! src/store */ "./src/store/index.ts"));
const constants_1 = __webpack_require__(/*! src/utils/constants */ "./src/utils/constants.ts");
const helpers_1 = __webpack_require__(/*! src/utils/helpers */ "./src/utils/helpers.ts");
class Container extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.handleResize = () => {
            this.setState({ windowWidth: window.innerWidth });
        };
        this.add = (notification) => {
            this.setState(({ notifications }) => {
                const nextNotifications = [...notifications];
                const i = nextNotifications.findIndex(({ id }) => id === notification.id);
                if (i > -1) {
                    nextNotifications[i] = notification;
                    return {
                        notifications: nextNotifications
                    };
                }
                return {
                    notifications: notification.insert === 'top'
                        ? [notification, ...nextNotifications]
                        : [...nextNotifications, notification]
                };
            });
            return notification.id;
        };
        this.remove = (id) => {
            this.setState(({ notifications }) => ({
                notifications: notifications.map((notification) => {
                    if (notification.id === id) {
                        notification.hasBeenRemoved = true;
                    }
                    return notification;
                })
            }));
        };
        this.removeAllNotifications = () => {
            this.setState({
                notifications: this.state.notifications.map((notification) => ({
                    ...notification,
                    hasBeenRemoved: true
                }))
            });
        };
        this.toggleRemoval = (id, callback) => {
            this.setState(({ notifications }) => ({
                notifications: notifications.filter(({ id: nId }) => nId !== id)
            }), callback);
        };
        this.state = {
            isMobile: (0, helpers_1.isNullOrUndefined)(props.isMobile) ? constants_1.DEFAULT_CONTAINER_VALUES.isMobile : props.isMobile,
            breakpoint: (0, helpers_1.isNullOrUndefined)(props.breakpoint) ? constants_1.DEFAULT_CONTAINER_VALUES.breakpoint : props.breakpoint,
            notifications: [],
            windowWidth: undefined
        };
    }
    componentDidMount() {
        const { types, defaultNotificationWidth } = this.props;
        store_1.default.register({
            addNotification: this.add,
            removeNotification: this.remove,
            removeAllNotifications: this.removeAllNotifications,
            defaultNotificationWidth: defaultNotificationWidth || constants_1.DEFAULT_CONTAINER_VALUES.defaultNotificationWidth,
            types
        });
        this.setState({ windowWidth: window.innerWidth });
        window.addEventListener('resize', this.handleResize);
    }
    componentWillUnmount() {
        window.removeEventListener('resize', this.handleResize);
    }
    renderNotifications(notifications, isMobile) {
        return notifications.map((notification) => (react_1.default.createElement(Notification_1.default, { id: notification.id, key: notification.id, isMobile: isMobile, defaultNotificationWidth: this.props.defaultNotificationWidth, notification: notification, toggleRemoval: this.toggleRemoval, notificationsCount: notifications.length, hasBeenRemoved: notification.hasBeenRemoved })));
    }
    renderMobileNotifications(props) {
        const { className, id } = props;
        const { notifications } = this.state;
        const mobileNotifications = (0, helpers_1.getNotificationsForMobileView)(notifications);
        const top = this.renderNotifications(mobileNotifications.top, true);
        const bottom = this.renderNotifications(mobileNotifications.bottom, true);
        return (react_1.default.createElement("div", { id: id, key: "mobile", className: `rnc__base ${className || ''}` },
            react_1.default.createElement("div", { className: "rnc__notification-container--mobile-top" }, top),
            react_1.default.createElement("div", { className: "rnc__notification-container--mobile-bottom" }, bottom)));
    }
    renderScreenNotifications(props) {
        const { className, id } = props;
        const { notifications } = this.state;
        const items = (0, helpers_1.getNotificationsForEachContainer)(notifications);
        const topFull = this.renderNotifications(items.topFull, false);
        const bottomFull = this.renderNotifications(items.bottomFull, false);
        const topLeft = this.renderNotifications(items.topLeft, false);
        const topRight = this.renderNotifications(items.topRight, false);
        const topCenter = this.renderNotifications(items.topCenter, false);
        const bottomLeft = this.renderNotifications(items.bottomLeft, false);
        const bottomRight = this.renderNotifications(items.bottomRight, false);
        const bottomCenter = this.renderNotifications(items.bottomCenter, false);
        const center = this.renderNotifications(items.center, false);
        return (react_1.default.createElement("div", { id: id, key: "screen", className: `rnc__base ${className || ''}` },
            react_1.default.createElement("div", { className: "rnc__notification-container--top-full" }, topFull),
            react_1.default.createElement("div", { className: "rnc__notification-container--bottom-full" }, bottomFull),
            react_1.default.createElement("div", { className: "rnc__notification-container--top-left" }, topLeft),
            react_1.default.createElement("div", { className: "rnc__notification-container--top-right" }, topRight),
            react_1.default.createElement("div", { className: "rnc__notification-container--bottom-left" }, bottomLeft),
            react_1.default.createElement("div", { className: "rnc__notification-container--bottom-right" }, bottomRight),
            react_1.default.createElement("div", { className: "rnc__notification-container--top-center" }, topCenter),
            react_1.default.createElement("div", { className: "rnc__notification-container--center" },
                react_1.default.createElement("div", { className: "rnc__util--flex-center" }, center)),
            react_1.default.createElement("div", { className: "rnc__notification-container--bottom-center" }, bottomCenter)));
    }
    render() {
        const { isMobile } = this.props;
        const { windowWidth, breakpoint } = this.state;
        if (isMobile && windowWidth <= breakpoint) {
            return this.renderMobileNotifications(this.props);
        }
        return this.renderScreenNotifications(this.props);
    }
}
exports["default"] = Container;


/***/ }),

/***/ "./src/components/Notification.tsx":
/*!*****************************************!*\
  !*** ./src/components/Notification.tsx ***!
  \*****************************************/
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
const react_1 = __importDefault(__webpack_require__(/*! react */ "react"));
const src_1 = __webpack_require__(/*! src */ "./src/index.ts");
const helpers_1 = __webpack_require__(/*! src/utils/helpers */ "./src/utils/helpers.ts");
const timer_1 = __importDefault(__webpack_require__(/*! src/utils/timer */ "./src/utils/timer.ts"));
class Notification extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.onClick = () => {
            const { notification: { dismiss } } = this.props;
            if (dismiss.click || dismiss.showIcon) {
                this.removeNotification(src_1.NOTIFICATION_REMOVAL_SOURCE.CLICK);
            }
        };
        this.onTouchStart = (event) => {
            const { pageX } = event.touches[0];
            this.setState(({ parentStyle }) => ({
                startX: pageX,
                currentX: pageX,
                parentStyle: {
                    ...parentStyle,
                    position: 'relative'
                }
            }));
        };
        this.onTouchMove = (event) => {
            const { pageX } = event.touches[0];
            const { startX } = this.state;
            const { toggleRemoval, notification: { id, onRemoval, slidingExit, touchSlidingExit: { swipe, fade } } } = this.props;
            const distance = pageX - startX;
            const { offsetWidth: width } = this.rootElementRef.current;
            const swipeTo = window.innerWidth + width;
            const left = `${pageX - startX >= 0 ? swipeTo : -swipeTo}px`;
            if ((0, helpers_1.hasFullySwiped)(distance, width)) {
                const t1 = (0, helpers_1.getTransition)(swipe, 'left');
                const t2 = (0, helpers_1.getTransition)(fade, 'opacity');
                const onTransitionEnd = () => {
                    toggleRemoval(id, () => onRemoval(id, src_1.NOTIFICATION_REMOVAL_SOURCE.TOUCH));
                };
                return this.setState(({ parentStyle }) => ({
                    touchEnabled: false,
                    parentStyle: {
                        ...parentStyle,
                        left,
                        opacity: 0,
                        transition: `${t1}, ${t2}`
                    },
                    onTransitionEnd: () => {
                        this.setState(({ parentStyle }) => ({
                            parentStyle: {
                                ...parentStyle,
                                height: `0px`,
                                overflow: 'hidden',
                                transition: (0, helpers_1.getTransition)(slidingExit, 'height')
                            },
                            onTransitionEnd
                        }));
                    }
                }));
            }
            return this.setState(({ parentStyle }) => ({
                currentX: pageX,
                parentStyle: {
                    ...parentStyle,
                    left: `${0 + distance}px`
                }
            }));
        };
        this.onTouchEnd = () => {
            const { notification: { touchRevert } } = this.props;
            this.setState(({ parentStyle }) => ({
                parentStyle: {
                    ...parentStyle,
                    left: 0,
                    transition: (0, helpers_1.getTransition)(touchRevert, 'left')
                }
            }));
        };
        this.onMouseEnter = () => {
            if (this.timer) {
                this.timer.pause();
            }
            else {
                this.setState({ animationPlayState: 'paused' });
            }
        };
        this.onMouseLeave = () => {
            if (this.timer) {
                this.timer.resume();
            }
            else {
                this.setState({ animationPlayState: 'running' });
            }
        };
        this.rootElementRef = react_1.default.createRef();
        const { defaultNotificationWidth, notification, isMobile } = props;
        const { width } = notification;
        this.state = {
            parentStyle: {
                height: `0px`,
                overflow: 'hidden',
                width: `${width ? width : defaultNotificationWidth}px`
            },
            htmlClassList: (0, helpers_1.getHtmlClassesForType)(notification),
            animationPlayState: 'running',
            touchEnabled: true
        };
        if (isMobile) {
            this.state.parentStyle.width = '100%';
        }
    }
    componentWillUnmount() {
        if (this.timer) {
            this.timer.clear();
        }
    }
    componentDidMount() {
        const { notification, notificationsCount } = this.props;
        const { dismiss: { duration, onScreen } } = notification;
        const willSlide = (0, helpers_1.shouldNotificationHaveSliding)(notification, notificationsCount);
        const { scrollHeight } = this.rootElementRef.current;
        const onTransitionEnd = () => {
            if (!duration || onScreen)
                return;
            const callback = () => this.removeNotification(src_1.NOTIFICATION_REMOVAL_SOURCE.TIMEOUT);
            this.timer = new timer_1.default(callback, duration);
        };
        const callback = () => {
            requestAnimationFrame(() => {
                this.setState((prevState) => ({
                    htmlClassList: [...notification.animationIn, ...prevState.htmlClassList]
                }));
            });
        };
        this.setState(({ parentStyle: { width } }) => ({
            parentStyle: {
                width,
                height: `${scrollHeight}px`,
                transition: willSlide ? (0, helpers_1.getTransition)(notification.slidingEnter, 'height') : '10ms height'
            },
            onTransitionEnd
        }), callback);
    }
    componentDidUpdate(prevProps) {
        if (this.props.hasBeenRemoved && !prevProps.hasBeenRemoved) {
            this.removeNotification(src_1.NOTIFICATION_REMOVAL_SOURCE.MANUAL);
        }
        if (prevProps !== this.props) {
            const { container } = this.props.notification;
            const { scrollHeight } = this.rootElementRef.current.children[0];
            this.setState(({ parentStyle }) => ({
                parentStyle: {
                    ...parentStyle,
                    height: `${scrollHeight + (container.endsWith('full') ? 0 : 15)}px`
                }
            }));
        }
    }
    removeNotification(removalFlag) {
        const { notification, toggleRemoval } = this.props;
        const { id, onRemoval, dismiss: { waitForAnimation } } = notification;
        const htmlClassList = [...notification.animationOut, ...(0, helpers_1.getHtmlClassesForType)(notification)];
        const onTransitionEnd = () => toggleRemoval(id, () => onRemoval(id, removalFlag));
        const parentStyle = {
            height: `0px`,
            overflow: 'hidden',
            transition: (0, helpers_1.getTransition)(notification.slidingExit, 'height')
        };
        if (waitForAnimation) {
            return this.setState(({ parentStyle: { width } }) => ({
                htmlClassList,
                onAnimationEnd: () => {
                    this.setState({
                        parentStyle: {
                            width,
                            ...parentStyle
                        },
                        onTransitionEnd
                    });
                }
            }));
        }
        return this.setState(({ parentStyle: { width } }) => ({
            parentStyle: {
                width,
                ...parentStyle
            },
            onTransitionEnd,
            htmlClassList
        }));
    }
    renderTimer() {
        const { notification: { dismiss } } = this.props;
        const { duration, onScreen } = dismiss;
        const { animationPlayState } = this.state;
        if (!duration || !onScreen) {
            return;
        }
        const style = {
            animationName: 'timer',
            animationDuration: `${duration}ms`,
            animationTimingFunction: 'linear',
            animationFillMode: 'forwards',
            animationDelay: `0`,
            animationPlayState
        };
        const onAnimationEnd = () => this.removeNotification(src_1.NOTIFICATION_REMOVAL_SOURCE.TIMEOUT);
        return (react_1.default.createElement("div", { className: "rnc__notification-timer" },
            react_1.default.createElement("div", { className: "rnc__notification-timer-filler", onAnimationEnd: onAnimationEnd, style: style })));
    }
    renderCustomContent() {
        const { htmlClassList } = this.state;
        const { notification: { id, content: CustomContent, dismiss: { duration, pauseOnHover } } } = this.props;
        const hasMouseEvents = duration > 0 && pauseOnHover;
        return (react_1.default.createElement("div", { className: `${[...htmlClassList].join(' ')}`, onMouseEnter: hasMouseEvents ? this.onMouseEnter : null, onMouseLeave: hasMouseEvents ? this.onMouseLeave : null }, react_1.default.isValidElement(CustomContent) ? CustomContent : react_1.default.createElement(CustomContent, { ...{ id } })));
    }
    renderNotification() {
        const { notification: { title, message, dismiss: { showIcon, duration, pauseOnHover } } } = this.props;
        const { htmlClassList } = this.state;
        const hasMouseEvents = duration > 0 && pauseOnHover;
        return (react_1.default.createElement("div", { className: `${[...htmlClassList].join(' ')}`, onMouseEnter: hasMouseEvents ? this.onMouseEnter : null, onMouseLeave: hasMouseEvents ? this.onMouseLeave : null },
            react_1.default.createElement("div", { className: "rnc__notification-content" },
                showIcon && react_1.default.createElement("div", { className: "rnc__notification-close-mark", onClick: this.onClick }),
                title && react_1.default.createElement("div", { className: "rnc__notification-title" }, title),
                react_1.default.createElement("div", { className: "rnc__notification-message" }, message),
                this.renderTimer())));
    }
    render() {
        const { notification: { content, dismiss: { click } } } = this.props;
        const { parentStyle, onAnimationEnd, onTransitionEnd, touchEnabled } = this.state;
        return (react_1.default.createElement("div", { ref: this.rootElementRef, onClick: click ? this.onClick : null, className: 'notification', style: parentStyle, onAnimationEnd: onAnimationEnd, onTransitionEnd: onTransitionEnd, onTouchStart: touchEnabled ? this.onTouchStart : null, onTouchMove: touchEnabled ? this.onTouchMove : null, onTouchEnd: touchEnabled ? this.onTouchEnd : null }, content ? this.renderCustomContent() : this.renderNotification()));
    }
}
exports["default"] = Notification;


/***/ }),

/***/ "./src/index.ts":
/*!**********************!*\
  !*** ./src/index.ts ***!
  \**********************/
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.NOTIFICATION_REMOVAL_SOURCE = exports.NOTIFICATION_INSERTION = exports.NOTIFICATION_TYPE = exports.NOTIFICATION_CONTAINER = exports.store = void 0;
const Container_1 = __importDefault(__webpack_require__(/*! src/components/Container */ "./src/components/Container.tsx"));
const store_1 = __importDefault(__webpack_require__(/*! src/store */ "./src/store/index.ts"));
exports.store = store_1.default;
exports["default"] = Container_1.default;
const types_1 = __webpack_require__(/*! ./types */ "./src/types.ts");
Object.defineProperty(exports, "NOTIFICATION_CONTAINER", ({ enumerable: true, get: function () { return types_1.NOTIFICATION_CONTAINER; } }));
Object.defineProperty(exports, "NOTIFICATION_TYPE", ({ enumerable: true, get: function () { return types_1.NOTIFICATION_TYPE; } }));
Object.defineProperty(exports, "NOTIFICATION_INSERTION", ({ enumerable: true, get: function () { return types_1.NOTIFICATION_INSERTION; } }));
Object.defineProperty(exports, "NOTIFICATION_REMOVAL_SOURCE", ({ enumerable: true, get: function () { return types_1.NOTIFICATION_REMOVAL_SOURCE; } }));


/***/ }),

/***/ "./src/store/index.ts":
/*!****************************!*\
  !*** ./src/store/index.ts ***!
  \****************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
const helpers_1 = __webpack_require__(/*! src/utils/helpers */ "./src/utils/helpers.ts");
const validators_1 = __webpack_require__(/*! src/utils/validators */ "./src/utils/validators.ts");
class Store {
    constructor() {
        this.incrementCounter = () => (this.counter += 1);
        this.getCounter = () => this.counter;
        this.counter = 0;
        this.add = null;
    }
    addNotification(notification) {
        if (true) {
            const transitions = ['slidingEnter', 'slidingExit', 'touchRevert', 'touchSlidingExit'];
            transitions.forEach((transition) => (0, validators_1.validateTransition)(notification, transition));
            validators_1.validators.forEach((validator) => validator(notification, this.types));
        }
        this.incrementCounter();
        const parsedNotification = (0, helpers_1.parseNotification)(notification, this.types, this.defaultNotificationWidth);
        return this.add(parsedNotification);
    }
    register(parameters) {
        const { addNotification, removeNotification, removeAllNotifications, types, defaultNotificationWidth } = parameters;
        this.add = addNotification;
        this.removeNotification = removeNotification;
        this.removeAllNotifications = removeAllNotifications;
        this.defaultNotificationWidth = defaultNotificationWidth;
        this.types = types;
    }
}
exports["default"] = new Store();


/***/ }),

/***/ "./src/types.ts":
/*!**********************!*\
  !*** ./src/types.ts ***!
  \**********************/
/***/ ((__unused_webpack_module, exports) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.NOTIFICATION_REMOVAL_SOURCE = exports.NOTIFICATION_TYPE = exports.NOTIFICATION_INSERTION = exports.NOTIFICATION_CONTAINER = void 0;
var NOTIFICATION_CONTAINER;
(function (NOTIFICATION_CONTAINER) {
    NOTIFICATION_CONTAINER["BOTTOM_LEFT"] = "bottom-left";
    NOTIFICATION_CONTAINER["BOTTOM_RIGHT"] = "bottom-right";
    NOTIFICATION_CONTAINER["BOTTOM_CENTER"] = "bottom-center";
    NOTIFICATION_CONTAINER["TOP_LEFT"] = "top-left";
    NOTIFICATION_CONTAINER["TOP_RIGHT"] = "top-right";
    NOTIFICATION_CONTAINER["TOP_CENTER"] = "top-center";
    NOTIFICATION_CONTAINER["CENTER"] = "center";
    NOTIFICATION_CONTAINER["TOP_FULL"] = "top-full";
    NOTIFICATION_CONTAINER["BOTTOM_FULL"] = "bottom-full";
})(NOTIFICATION_CONTAINER || (NOTIFICATION_CONTAINER = {}));
exports.NOTIFICATION_CONTAINER = NOTIFICATION_CONTAINER;
var NOTIFICATION_INSERTION;
(function (NOTIFICATION_INSERTION) {
    NOTIFICATION_INSERTION["TOP"] = "top";
    NOTIFICATION_INSERTION["BOTTOM"] = "bottom";
})(NOTIFICATION_INSERTION || (NOTIFICATION_INSERTION = {}));
exports.NOTIFICATION_INSERTION = NOTIFICATION_INSERTION;
var NOTIFICATION_TYPE;
(function (NOTIFICATION_TYPE) {
    NOTIFICATION_TYPE["SUCCESS"] = "success";
    NOTIFICATION_TYPE["DANGER"] = "danger";
    NOTIFICATION_TYPE["INFO"] = "info";
    NOTIFICATION_TYPE["DEFAULT"] = "default";
    NOTIFICATION_TYPE["WARNING"] = "warning";
})(NOTIFICATION_TYPE || (NOTIFICATION_TYPE = {}));
exports.NOTIFICATION_TYPE = NOTIFICATION_TYPE;
var NOTIFICATION_REMOVAL_SOURCE;
(function (NOTIFICATION_REMOVAL_SOURCE) {
    NOTIFICATION_REMOVAL_SOURCE["TIMEOUT"] = "timeout";
    NOTIFICATION_REMOVAL_SOURCE["CLICK"] = "click";
    NOTIFICATION_REMOVAL_SOURCE["TOUCH"] = "touch";
    NOTIFICATION_REMOVAL_SOURCE["MANUAL"] = "manual";
})(NOTIFICATION_REMOVAL_SOURCE || (NOTIFICATION_REMOVAL_SOURCE = {}));
exports.NOTIFICATION_REMOVAL_SOURCE = NOTIFICATION_REMOVAL_SOURCE;


/***/ }),

/***/ "./src/utils/constants.ts":
/*!********************************!*\
  !*** ./src/utils/constants.ts ***!
  \********************************/
/***/ ((__unused_webpack_module, exports) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.ERROR = exports.NOTIFICATION_BASE_CLASS = exports.DEFAULT_CONTAINER_VALUES = void 0;
exports.DEFAULT_CONTAINER_VALUES = {
    isMobile: true,
    breakpoint: 768,
    defaultNotificationWidth: 325
};
exports.NOTIFICATION_BASE_CLASS = 'rnc__notification-item';
exports.ERROR = {
    ANIMATION_IN: 'Validation error. `animationIn` option must be an array',
    ANIMATION_OUT: 'Validation error. `animationOut` option must be an array',
    DISMISS_REQUIRED: 'Validation error. `duration` property of `dismiss` option is required',
    DISMISS_NUMBER: 'Validation error. `duration` property of `dismiss` option must be a Number',
    DISMISS_POSITIVE: 'Validation error. `duration` property of `dismiss` option must be a positive Number',
    DISMISS_CLICK_BOOL: 'Validation error. `click` property of `dismiss` option must be a Boolean',
    DISMISS_TOUCH_BOOL: 'Validation error. `touch` property of `dismiss` option must be a Boolean',
    DISMISS_WAIT: 'Validation error. `waitForAnimation` property of `dismiss` option must be a Boolean',
    DISMISS_PAUSE_BOOL: 'Validation error. `pauseOnHover` property of `dismiss` option must be a Boolean',
    DISMISS_ONSCREEN_BOOL: 'Validation error. `onScreen` property of `dismiss` option must be a Boolean',
    DISMISS_ICON: 'Validation error. `showIcon` property of `dismiss` option must be a Boolean',
    TITLE_STRING: 'Validation error. `title` option must be a String',
    TITLE_ELEMENT: 'Validation error. `title` option must be a valid React element/function',
    MESSAGE_REQUIRED: 'Validation error. `message` option is required',
    MESSAGE_STRING: 'Validation error. `message` option must be a String',
    MESSAGE_ELEMENT: 'Validation error. `message` option must be a valid React element/function',
    TYPE_REQUIRED: 'Validation error. `type` option is required',
    TYPE_STRING: 'Validation error. `type` option must be a String',
    TYPE_NOT_EXISTENT: 'Validation error. `type` option not found',
    CONTAINER_REQUIRED: 'Validation error. `container` option is required',
    CONTAINER_STRING: 'Validation error. `container` option must be a String',
    CONTENT_INVALID: 'Validation error. `content` option must be a valid React component/function/element',
    WIDTH_NUMBER: 'Validation error. `width` option must be a Number',
    INSERT_STRING: 'Validation error. `insert` option must be a String',
    TRANSITION_DURATION_NUMBER: 'Validation error. `duration` property of `transition` option must be a Number',
    TRANSITION_TIMING_FUNCTION: 'Validation error. `timingFunction` property of `transition` option must be a String',
    TRANSITION_DELAY_NUMBER: 'Validation error. `delay` property of `transition` option must be a Number',
    TYPE_NOT_FOUND: 'Validation error. Custom type not found',
    REMOVAL_FUNC: 'Validation error. `onRemoval` must be a function'
};


/***/ }),

/***/ "./src/utils/helpers.ts":
/*!******************************!*\
  !*** ./src/utils/helpers.ts ***!
  \******************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.parseNotification = exports.getUid = exports.getTransition = exports.getNotificationsForEachContainer = exports.getNotificationsForMobileView = exports.getHtmlClassesForType = exports.htmlClassesForExistingType = exports.shouldNotificationHaveSliding = exports.hasFullySwiped = exports.isTopContainer = exports.isBottomContainer = exports.isNullOrUndefined = void 0;
const types_1 = __webpack_require__(/*! src/types */ "./src/types.ts");
const constants_1 = __webpack_require__(/*! src/utils/constants */ "./src/utils/constants.ts");
const isNullOrUndefined = (object) => object === null || object === undefined;
exports.isNullOrUndefined = isNullOrUndefined;
function isBottomContainer(container) {
    return (container === types_1.NOTIFICATION_CONTAINER.BOTTOM_FULL ||
        container === types_1.NOTIFICATION_CONTAINER.BOTTOM_LEFT ||
        container === types_1.NOTIFICATION_CONTAINER.BOTTOM_RIGHT ||
        container === types_1.NOTIFICATION_CONTAINER.BOTTOM_CENTER);
}
exports.isBottomContainer = isBottomContainer;
function isTopContainer(container) {
    return (container === types_1.NOTIFICATION_CONTAINER.TOP_FULL ||
        container === types_1.NOTIFICATION_CONTAINER.TOP_LEFT ||
        container === types_1.NOTIFICATION_CONTAINER.TOP_RIGHT ||
        container === types_1.NOTIFICATION_CONTAINER.TOP_CENTER);
}
exports.isTopContainer = isTopContainer;
function hasFullySwiped(diffX, width) {
    const swipeLength = Math.abs(diffX);
    const requiredSwipeLength = (40 / 100) * width;
    return swipeLength >= requiredSwipeLength;
}
exports.hasFullySwiped = hasFullySwiped;
function shouldNotificationHaveSliding(notification, count) {
    if (count <= 1) {
        return false;
    }
    return (count > 1 &&
        ((notification.insert === types_1.NOTIFICATION_INSERTION.TOP && isTopContainer(notification.container)) ||
            (notification.insert === types_1.NOTIFICATION_INSERTION.BOTTOM && isBottomContainer(notification.container)) ||
            notification.container === types_1.NOTIFICATION_CONTAINER.CENTER));
}
exports.shouldNotificationHaveSliding = shouldNotificationHaveSliding;
function htmlClassesForExistingType(type) {
    switch (type) {
        case types_1.NOTIFICATION_TYPE.DEFAULT:
            return [constants_1.NOTIFICATION_BASE_CLASS, 'rnc__notification-item--default'];
        case types_1.NOTIFICATION_TYPE.SUCCESS:
            return [constants_1.NOTIFICATION_BASE_CLASS, 'rnc__notification-item--success'];
        case types_1.NOTIFICATION_TYPE.DANGER:
            return [constants_1.NOTIFICATION_BASE_CLASS, 'rnc__notification-item--danger'];
        case types_1.NOTIFICATION_TYPE.WARNING:
            return [constants_1.NOTIFICATION_BASE_CLASS, 'rnc__notification-item--warning'];
        case types_1.NOTIFICATION_TYPE.INFO:
            return [constants_1.NOTIFICATION_BASE_CLASS, 'rnc__notification-item--info'];
        default:
            return [constants_1.NOTIFICATION_BASE_CLASS];
    }
}
exports.htmlClassesForExistingType = htmlClassesForExistingType;
function getHtmlClassesForType(notification) {
    const { type, content, userDefinedTypes } = notification;
    const base = [constants_1.NOTIFICATION_BASE_CLASS];
    if (content) {
        return base;
    }
    if ((0, exports.isNullOrUndefined)(userDefinedTypes)) {
        return htmlClassesForExistingType(type);
    }
    const foundType = userDefinedTypes.find((q) => q.name === type);
    return base.concat(foundType.htmlClasses);
}
exports.getHtmlClassesForType = getHtmlClassesForType;
function getNotificationsForMobileView(notifications) {
    const top = [];
    const bottom = [];
    notifications.forEach((notification) => {
        const { container } = notification;
        const { CENTER } = types_1.NOTIFICATION_CONTAINER;
        if (isTopContainer(container) || container === CENTER) {
            top.push(notification);
        }
        else if (isBottomContainer(container)) {
            bottom.push(notification);
        }
    });
    return { top, bottom };
}
exports.getNotificationsForMobileView = getNotificationsForMobileView;
function getNotificationsForEachContainer(notifications) {
    const topLeft = [];
    const topRight = [];
    const topCenter = [];
    const bottomLeft = [];
    const bottomRight = [];
    const bottomCenter = [];
    const center = [];
    const topFull = [];
    const bottomFull = [];
    notifications.forEach((notification) => {
        const { container } = notification;
        if (container === types_1.NOTIFICATION_CONTAINER.TOP_FULL) {
            topFull.push(notification);
        }
        else if (container === types_1.NOTIFICATION_CONTAINER.BOTTOM_FULL) {
            bottomFull.push(notification);
        }
        else if (container === types_1.NOTIFICATION_CONTAINER.TOP_LEFT) {
            topLeft.push(notification);
        }
        else if (container === types_1.NOTIFICATION_CONTAINER.TOP_RIGHT) {
            topRight.push(notification);
        }
        else if (container === types_1.NOTIFICATION_CONTAINER.TOP_CENTER) {
            topCenter.push(notification);
        }
        else if (container === types_1.NOTIFICATION_CONTAINER.BOTTOM_LEFT) {
            bottomLeft.push(notification);
        }
        else if (container === types_1.NOTIFICATION_CONTAINER.BOTTOM_RIGHT) {
            bottomRight.push(notification);
        }
        else if (container === types_1.NOTIFICATION_CONTAINER.BOTTOM_CENTER) {
            bottomCenter.push(notification);
        }
        else if (container === types_1.NOTIFICATION_CONTAINER.CENTER) {
            center.push(notification);
        }
    });
    return {
        topFull,
        bottomFull,
        topLeft,
        topRight,
        topCenter,
        bottomLeft,
        bottomRight,
        bottomCenter,
        center
    };
}
exports.getNotificationsForEachContainer = getNotificationsForEachContainer;
function getTransition({ duration, timingFunction, delay }, property) {
    return `${duration}ms ${property} ${timingFunction} ${delay}ms`;
}
exports.getTransition = getTransition;
function getUid(a) {
    return a ? (0 | (Math.random() * 16)).toString(16) : ('' + 1e11 + 1e11).replace(/1|0/g, getUid);
}
exports.getUid = getUid;
function defaultTransition(transition, { duration, timingFunction, delay }) {
    const transitionOptions = transition || {};
    if ((0, exports.isNullOrUndefined)(transitionOptions.duration)) {
        transitionOptions.duration = duration;
    }
    if ((0, exports.isNullOrUndefined)(transitionOptions.timingFunction)) {
        transitionOptions.timingFunction = timingFunction;
    }
    if ((0, exports.isNullOrUndefined)(transitionOptions.delay)) {
        transitionOptions.delay = delay;
    }
    return transitionOptions;
}
function defaultDismiss(dismiss) {
    const option = dismiss;
    const defaults = {
        duration: 0,
        click: true,
        touch: true,
        onScreen: false,
        pauseOnHover: false,
        waitForAnimation: false,
        showIcon: false
    };
    if (!option) {
        return defaults;
    }
    Object.keys(defaults).forEach((prop) => {
        if ((0, exports.isNullOrUndefined)(option[prop])) {
            option[prop] = defaults[prop];
        }
    });
    return option;
}
function defaultUserDefinedTypes(notification, definedTypes) {
    const { content, type } = notification;
    if (content) {
        return undefined;
    }
    if (type === types_1.NOTIFICATION_TYPE.SUCCESS ||
        type === types_1.NOTIFICATION_TYPE.DANGER ||
        type === types_1.NOTIFICATION_TYPE.INFO ||
        type === types_1.NOTIFICATION_TYPE.DEFAULT ||
        type === types_1.NOTIFICATION_TYPE.WARNING ||
        !definedTypes) {
        return undefined;
    }
    return definedTypes;
}
function parseNotification(options, userDefinedTypes, defaultNotificationWidth) {
    const notification = options;
    const { id, type, insert, content, container, animationIn, animationOut, slidingEnter, slidingExit, touchRevert, touchSlidingExit, dismiss, width, onRemoval } = notification;
    notification.id = id || getUid();
    notification.type = content ? null : type.toLowerCase();
    if (userDefinedTypes && !content) {
        notification.userDefinedTypes = defaultUserDefinedTypes(notification, userDefinedTypes);
    }
    notification.width = (0, exports.isNullOrUndefined)(width) ? defaultNotificationWidth : width;
    notification.container = container.toLowerCase();
    notification.insert = (insert || 'top').toLowerCase();
    notification.dismiss = defaultDismiss(dismiss);
    notification.animationIn = animationIn || [];
    notification.animationOut = animationOut || [];
    // eslint-disable-next-line
    notification.onRemoval = onRemoval || (() => { });
    const t = (duration, timingFunction, delay) => ({
        duration,
        timingFunction,
        delay
    });
    notification.slidingEnter = defaultTransition(slidingEnter, t(600, 'linear', 0));
    notification.slidingExit = defaultTransition(slidingExit, t(600, 'linear', 0));
    notification.touchRevert = defaultTransition(touchRevert, t(600, 'linear', 0));
    const touchExit = touchSlidingExit || {};
    const swipe = touchExit.swipe || {};
    const fade = touchExit.fade || {};
    notification.touchSlidingExit = touchExit;
    notification.touchSlidingExit.swipe = defaultTransition(swipe, t(600, 'linear', 0));
    notification.touchSlidingExit.fade = defaultTransition(fade, t(300, 'linear', 0));
    return notification;
}
exports.parseNotification = parseNotification;


/***/ }),

/***/ "./src/utils/timer.ts":
/*!****************************!*\
  !*** ./src/utils/timer.ts ***!
  \****************************/
/***/ ((__unused_webpack_module, exports) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
class Timer {
    constructor(callback, delay) {
        this.callback = callback;
        this.remaining = delay;
        this.resume();
    }
    pause() {
        clearTimeout(this.timerId);
        this.remaining -= Date.now() - this.start;
    }
    resume() {
        this.start = Date.now();
        clearTimeout(this.timerId);
        this.timerId = setTimeout(this.callback, this.remaining);
    }
    clear() {
        clearTimeout(this.timerId);
    }
}
exports["default"] = Timer;


/***/ }),

/***/ "./src/utils/validators.ts":
/*!*********************************!*\
  !*** ./src/utils/validators.ts ***!
  \*********************************/
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.validators = exports.validateTransition = void 0;
const react_1 = __importDefault(__webpack_require__(/*! react */ "react"));
const types_1 = __webpack_require__(/*! src/types */ "./src/types.ts");
const constants_1 = __webpack_require__(/*! src/utils/constants */ "./src/utils/constants.ts");
const isNullOrUndefined = (object) => object === null || object === undefined;
const isString = (object) => typeof object === 'string';
const isNumber = (object) => typeof object === 'number';
const isBoolean = (object) => typeof object === 'boolean';
const isFunction = (object) => !!(object && object.constructor && object.call && object.apply);
const isArray = (object) => !isNullOrUndefined(object) && object.constructor === Array;
function isClassComponent(component) {
    return typeof component === 'function' && component.prototype && !!component.prototype.render;
}
function isFunctionComponent(component) {
    return typeof component === 'function';
}
const isReactElement = (value) => isFunctionComponent(value) || react_1.default.isValidElement(value);
function validateTransition(notification, transition) {
    const { TRANSITION_DURATION_NUMBER, TRANSITION_TIMING_FUNCTION, TRANSITION_DELAY_NUMBER } = constants_1.ERROR;
    const { duration, timingFunction, delay } = notification[transition] || {};
    if (!isNullOrUndefined(duration) && !isNumber(duration)) {
        throw new Error(TRANSITION_DURATION_NUMBER.replace('transition', transition));
    }
    if (!isNullOrUndefined(timingFunction) && !isString(timingFunction)) {
        throw new Error(TRANSITION_TIMING_FUNCTION.replace('transition', transition));
    }
    if (!isNullOrUndefined(delay) && !isNumber(delay)) {
        throw new Error(TRANSITION_DELAY_NUMBER.replace('transition', transition));
    }
}
exports.validateTransition = validateTransition;
exports.validators = [
    function title({ content, title: _title }) {
        if (content)
            return;
        if (isNullOrUndefined(_title))
            return;
        const isReactEl = isReactElement(_title);
        if (isReactEl || typeof _title === 'string')
            return;
        if (!isReactEl) {
            throw new Error(constants_1.ERROR.TITLE_ELEMENT);
        }
        if (typeof _title !== 'string') {
            throw new Error(constants_1.ERROR.TITLE_STRING);
        }
    },
    function message({ content, message: _message }) {
        if (content)
            return;
        if (!_message) {
            throw new Error(constants_1.ERROR.MESSAGE_REQUIRED);
        }
        const isReactEl = isReactElement(_message);
        if (isString(_message) || isReactEl) {
            return;
        }
        if (!isString(_message)) {
            throw new Error(constants_1.ERROR.MESSAGE_STRING);
        }
        if (!isReactEl) {
            throw new Error(constants_1.ERROR.MESSAGE_ELEMENT);
        }
    },
    function type({ content, type: _type }, userDefinedTypes) {
        if (content)
            return;
        if (!_type) {
            throw new Error(constants_1.ERROR.TYPE_REQUIRED);
        }
        if (!isString(_type)) {
            throw new Error(constants_1.ERROR.TYPE_STRING);
        }
        if (!userDefinedTypes &&
            _type !== types_1.NOTIFICATION_TYPE.SUCCESS &&
            _type !== types_1.NOTIFICATION_TYPE.DANGER &&
            _type !== types_1.NOTIFICATION_TYPE.INFO &&
            _type !== types_1.NOTIFICATION_TYPE.DEFAULT &&
            _type !== types_1.NOTIFICATION_TYPE.WARNING) {
            throw new Error(constants_1.ERROR.TYPE_NOT_EXISTENT);
        }
    },
    function container({ container: _container }) {
        if (isNullOrUndefined(_container)) {
            throw new Error(constants_1.ERROR.CONTAINER_REQUIRED);
        }
        if (!isString(_container)) {
            throw new Error(constants_1.ERROR.CONTAINER_STRING);
        }
    },
    function insert({ insert: _insert }) {
        if (isNullOrUndefined(_insert))
            return;
        if (!isString(_insert)) {
            throw new Error(constants_1.ERROR.INSERT_STRING);
        }
    },
    function width({ width: _width }) {
        if (isNullOrUndefined(_width))
            return;
        if (!isNumber(_width)) {
            throw new Error(constants_1.ERROR.WIDTH_NUMBER);
        }
    },
    function userDefinedTypes({ type, content }, _userDefinedTypes) {
        if (content)
            return;
        if (type === types_1.NOTIFICATION_TYPE.SUCCESS ||
            type === types_1.NOTIFICATION_TYPE.DANGER ||
            type === types_1.NOTIFICATION_TYPE.INFO ||
            type === types_1.NOTIFICATION_TYPE.DEFAULT ||
            type === types_1.NOTIFICATION_TYPE.WARNING ||
            !_userDefinedTypes) {
            return;
        }
        if (!_userDefinedTypes.find((p) => p.name === type)) {
            throw new Error(constants_1.ERROR.TYPE_NOT_FOUND);
        }
    },
    function content({ content: _content }) {
        if (!_content)
            return;
        const isClass = isClassComponent(_content);
        const isFunction = isFunctionComponent(_content);
        const isElem = react_1.default.isValidElement(_content);
        if (!isClass && !isFunction && !isElem) {
            throw new Error(constants_1.ERROR.CONTENT_INVALID);
        }
    },
    function animationIn({ animationIn: _animationIn }) {
        if (isNullOrUndefined(_animationIn))
            return;
        if (!isArray(_animationIn)) {
            throw new Error(constants_1.ERROR.ANIMATION_IN);
        }
    },
    function animationOut({ animationOut: _animationOut }) {
        if (isNullOrUndefined(_animationOut))
            return;
        if (!isArray(_animationOut)) {
            throw new Error(constants_1.ERROR.ANIMATION_OUT);
        }
    },
    function onRemoval({ onRemoval: _onRemoval }) {
        if (!_onRemoval)
            return;
        if (!isFunction(_onRemoval)) {
            throw new Error(constants_1.ERROR.REMOVAL_FUNC);
        }
    },
    function dismiss({ dismiss: _dismiss }) {
        if (!_dismiss)
            return;
        const { duration, onScreen, showIcon, pauseOnHover, waitForAnimation: wait, click, touch } = _dismiss;
        if (isNullOrUndefined(duration)) {
            throw new Error(constants_1.ERROR.DISMISS_REQUIRED);
        }
        if (!isNumber(duration)) {
            throw new Error(constants_1.ERROR.DISMISS_NUMBER);
        }
        if (duration < 0) {
            throw new Error(constants_1.ERROR.DISMISS_POSITIVE);
        }
        if (!isNullOrUndefined(onScreen) && !isBoolean(onScreen)) {
            throw new Error(constants_1.ERROR.DISMISS_ONSCREEN_BOOL);
        }
        if (!isNullOrUndefined(pauseOnHover) && !isBoolean(pauseOnHover)) {
            throw new Error(constants_1.ERROR.DISMISS_PAUSE_BOOL);
        }
        if (!isNullOrUndefined(click) && !isBoolean(click)) {
            throw new Error(constants_1.ERROR.DISMISS_CLICK_BOOL);
        }
        if (!isNullOrUndefined(touch) && !isBoolean(touch)) {
            throw new Error(constants_1.ERROR.DISMISS_TOUCH_BOOL);
        }
        if (!isNullOrUndefined(showIcon) && !isBoolean(showIcon)) {
            throw new Error(constants_1.ERROR.DISMISS_ICON);
        }
        if (!isNullOrUndefined(wait) && !isBoolean(wait)) {
            throw new Error(constants_1.ERROR.DISMISS_WAIT);
        }
    }
];


/***/ }),

/***/ "./src/scss/notification.scss":
/*!************************************!*\
  !*** ./src/scss/notification.scss ***!
  \************************************/
/***/ ((module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _node_modules_css_loader_dist_runtime_sourceMaps_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../node_modules/css-loader/dist/runtime/sourceMaps.js */ "./node_modules/css-loader/dist/runtime/sourceMaps.js");
/* harmony import */ var _node_modules_css_loader_dist_runtime_sourceMaps_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_css_loader_dist_runtime_sourceMaps_js__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../node_modules/css-loader/dist/runtime/api.js */ "./node_modules/css-loader/dist/runtime/api.js");
/* harmony import */ var _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__);
// Imports


var ___CSS_LOADER_EXPORT___ = _node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default()((_node_modules_css_loader_dist_runtime_sourceMaps_js__WEBPACK_IMPORTED_MODULE_0___default()));
// Module
___CSS_LOADER_EXPORT___.push([module.id, ".rnc__notification-container--top-center,\n.rnc__notification-container--top-left,\n.rnc__notification-container--top-right,\n.rnc__notification-container--bottom-center,\n.rnc__notification-container--bottom-left,\n.rnc__notification-container--bottom-right,\n.rnc__notification-container--center,\n.rnc__notification-container--top-full,\n.rnc__notification-container--bottom-full {\n  min-width: 325px;\n  position: absolute;\n  pointer-events: all; }\n\n.rnc__notification-container--center,\n.rnc__notification-container--top-center,\n.rnc__notification-container--bottom-center {\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  flex-direction: column;\n  left: calc(50% - 175px); }\n\n.rnc__notification-container--center,\n.rnc__notification-container--top-center,\n.rnc__notification-container--bottom-center {\n  max-width: 350px; }\n\n.rnc__notification-container--center {\n  top: 20px;\n  height: 100%;\n  pointer-events: none; }\n\n.rnc__notification-container--top-full,\n.rnc__notification-container--bottom-full {\n  width: 100%;\n  min-width: 100%; }\n\n.rnc__notification-container--bottom-full {\n  bottom: 0; }\n\n.rnc__util--flex-center {\n  min-width: 325px;\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  flex-direction: column;\n  pointer-events: all; }\n\n.rnc__notification-container--top-center {\n  top: 20px; }\n\n.rnc__notification-container--bottom-center {\n  bottom: 20px; }\n\n.rnc__notification-container--top-left {\n  left: 20px;\n  top: 20px; }\n\n.rnc__notification-container--top-right {\n  right: 20px;\n  top: 20px; }\n\n.rnc__notification-container--bottom-left {\n  left: 20px;\n  bottom: 20px; }\n\n.rnc__notification-container--bottom-right {\n  bottom: 20px;\n  right: 20px; }\n\n.rnc__notification-container--mobile-top,\n.rnc__notification-container--mobile-bottom {\n  pointer-events: all;\n  position: absolute; }\n\n.rnc__notification-container--mobile-top {\n  right: 20px;\n  left: 20px;\n  top: 20px; }\n\n.rnc__notification-container--mobile-bottom {\n  right: 20px;\n  left: 20px;\n  bottom: 20px;\n  margin-bottom: -15px; }\n\n.rnc__notification-item--default {\n  background-color: #007bff;\n  border-left: 8px solid #0562c7; }\n  .rnc__notification-item--default .rnc__notification-timer {\n    background-color: #007bff; }\n  .rnc__notification-item--default .rnc__notification-timer-filler {\n    background-color: #fff; }\n  .rnc__notification-item--default .rnc__notification-close-mark {\n    background-color: #007bff; }\n\n.rnc__notification-item--success {\n  background-color: #28a745;\n  border-left: 8px solid #1f8838; }\n  .rnc__notification-item--success .rnc__notification-timer {\n    background-color: #28a745; }\n  .rnc__notification-item--success .rnc__notification-timer-filler {\n    background-color: #fff; }\n  .rnc__notification-item--success .rnc__notification-close-mark {\n    background-color: #28a745; }\n\n.rnc__notification-item--danger {\n  background-color: #dc3545;\n  border-left: 8px solid #bd1120; }\n  .rnc__notification-item--danger .rnc__notification-timer {\n    background-color: #dc3545; }\n  .rnc__notification-item--danger .rnc__notification-timer-filler {\n    background-color: #fff; }\n  .rnc__notification-item--danger .rnc__notification-close-mark {\n    background-color: #dc3545; }\n\n.rnc__notification-item--info {\n  background-color: #17a2b8;\n  border-left: 8px solid #138b9e; }\n  .rnc__notification-item--info .rnc__notification-timer {\n    background-color: #17a2b8; }\n  .rnc__notification-item--info .rnc__notification-timer-filler {\n    background-color: #fff; }\n  .rnc__notification-item--info .rnc__notification-close-mark {\n    background-color: #17a2b8; }\n\n.rnc__notification-item--warning {\n  background-color: #eab000;\n  border-left: 8px solid #ce9c09; }\n  .rnc__notification-item--warning .rnc__notification-timer {\n    background-color: #eab000; }\n  .rnc__notification-item--warning .rnc__notification-timer-filler {\n    background-color: #fff; }\n  .rnc__notification-item--warning .rnc__notification-close-mark {\n    background-color: #eab000; }\n\n.rnc__notification-item--awesome {\n  background-color: #685dc3;\n  border-left: 8px solid #4c3fb1; }\n  .rnc__notification-item--awesome .rnc__notification-timer {\n    background-color: #685dc3; }\n  .rnc__notification-item--awesome .rnc__notification-timer-filler {\n    background-color: #fff; }\n  .rnc__notification-item--awesome .rnc__notification-close-mark {\n    background-color: #685dc3; }\n\n@keyframes timer {\n  0% {\n    width: 100%; }\n  100% {\n    width: 0%; } }\n\n.rnc__base {\n  position: fixed;\n  z-index: 9000;\n  pointer-events: none;\n  width: 100%;\n  height: 100%; }\n\n.rnc__notification-item {\n  display: flex;\n  position: relative;\n  border-radius: 3px;\n  margin-bottom: 15px;\n  box-shadow: 1px 3px 4px rgba(0, 0, 0, 0.2);\n  cursor: pointer; }\n\n.rnc__notification-container--top-full .rnc__notification-item,\n.rnc__notification-container--bottom-full .rnc__notification-item {\n  margin-bottom: 0;\n  border-radius: 0; }\n\n.rnc__notification-timer {\n  width: 100%;\n  height: 3px;\n  margin-top: 10px;\n  border-radius: 5px; }\n\n.rnc__notification-timer-filler {\n  height: 3px;\n  border-radius: 5px; }\n\n.rnc__notification-title {\n  color: #fff;\n  font-weight: 700;\n  font-size: 14px;\n  margin-top: 5px;\n  margin-bottom: 5px; }\n\n.rnc__notification-message {\n  color: #fff;\n  max-width: calc(100% - 15px);\n  font-size: 14px;\n  line-height: 150%;\n  word-wrap: break-word;\n  margin-bottom: 0;\n  margin-top: 0; }\n\n.rnc__notification-content {\n  padding: 8px 15px;\n  display: inline-block;\n  width: 100%; }\n\n.rnc__notification-close-mark {\n  width: 18px;\n  height: 18px;\n  border-radius: 50%;\n  display: inline-block;\n  position: absolute;\n  right: 10px;\n  top: 10px; }\n  .rnc__notification-close-mark::after {\n    content: '\\D7';\n    position: absolute;\n    transform: translate(-50%, -50%);\n    color: #fff;\n    font-size: 12px;\n    left: 50%;\n    top: 50%; }\n\n.rnc__notification-container--mobile-top .rnc__notification-item,\n.rnc__notification-container--mobile-bottom .rnc__notification-item,\n.rnc__notification-container--mobile-top .notification,\n.rnc__notification-container--mobile-bottom .notification {\n  max-width: 100%;\n  width: 100%; }\n\n.rnc__notification-container--top-right .notification,\n.rnc__notification-container--bottom-right .notification {\n  margin-left: auto; }\n\n.rnc__notification-container--top-left .notification,\n.rnc__notification-container--bottom-left .notification {\n  margin-right: auto; }\n\n.rnc__notification-container--mobile-top .notification,\n.rnc__notification-container--mobile-bottom .notification {\n  margin-left: auto;\n  margin-right: auto; }\n", "",{"version":3,"sources":["webpack://./src/scss/_containers.scss","webpack://./src/scss/_types.scss","webpack://./src/scss/_variables.scss","webpack://./src/scss/notification.scss"],"names":[],"mappings":"AAAA;;;;;;;;;EASE,gBAAgB;EAChB,kBAAkB;EAClB,mBAAmB,EAAA;;AAGrB;;;EAGE,aAAa;EACb,uBAAuB;EACvB,mBAAmB;EACnB,sBAAsB;EACtB,uBAAuB,EAAA;;AAGzB;;;EAGE,gBAAgB,EAAA;;AAGlB;EACE,SAAS;EACT,YAAY;EACZ,oBAAoB,EAAA;;AAGtB;;EAEE,WAAW;EACX,eAAe,EAAA;;AAGjB;EACE,SAAS,EAAA;;AAGX;EACE,gBAAgB;EAChB,aAAa;EACb,uBAAuB;EACvB,mBAAmB;EACnB,sBAAsB;EACtB,mBAAmB,EAAA;;AAGrB;EACE,SAAS,EAAA;;AAEX;EACE,YAAY,EAAA;;AAGd;EACE,UAAU;EACV,SAAS,EAAA;;AAGX;EACE,WAAW;EACX,SAAS,EAAA;;AAGX;EACE,UAAU;EACV,YAAY,EAAA;;AAGd;EACE,YAAY;EACZ,WAAW,EAAA;;AAGb;;EAEE,mBAAmB;EACnB,kBAAkB,EAAA;;AAGpB;EACE,WAAW;EACX,UAAU;EACV,SAAS,EAAA;;AAGX;EACE,WAAW;EACX,UAAU;EACV,YAAY;EACZ,oBAAoB,EAAA;;AChGtB;EACE,yBCHe;EDIf,8BCHoB,EAAA;EDCtB;IAKI,yBCWmB,EAAA;EDhBvB;IAQI,sBCSuB,EAAA;EDjB3B;IAWI,yBCba,EAAA;;ADiBjB;EACE,yBCfe;EDgBf,8BCfoB,EAAA;EDatB;IAKI,yBCDmB,EAAA;EDJvB;IAQI,sBCHuB,EAAA;EDL3B;IAWI,yBCzBa,EAAA;;AD6BjB;EACE,yBC3Bc;ED4Bd,8BC3BmB,EAAA;EDyBrB;IAKI,yBCbkB,EAAA;EDQtB;IAQI,sBCfsB,EAAA;EDO1B;IAWI,yBCrCY,EAAA;;ADyChB;EACE,yBCvCY;EDwCZ,8BCvCiB,EAAA;EDqCnB;IAKI,yBCzBgB,EAAA;EDoBpB;IAQI,sBC3BoB,EAAA;EDmBxB;IAWI,yBCjDU,EAAA;;ADqDd;EACE,yBCnDe;EDoDf,8BCnDoB,EAAA;EDiDtB;IAKI,yBCrCmB,EAAA;EDgCvB;IAQI,sBCvCuB,EAAA;ED+B3B;IAWI,yBC7Da,EAAA;;ADiEjB;EACE,yBC/De;EDgEf,8BC/DoB,EAAA;ED6DtB;IAKI,yBCjDmB,EAAA;ED4CvB;IAQI,sBCnDuB,EAAA;ED2C3B;IAWI,yBCzEa,EAAA;;ACZjB;EACE;IAAK,WAAW,EAAA;EAChB;IAAO,SAAS,EAAA,EAAA;;AAGlB;EACE,eAAe;EACf,aAAa;EACb,oBAAoB;EACpB,WAAW;EACX,YAAY,EAAA;;AAGd;EACE,aAAa;EACb,kBAAkB;EAClB,kBAAkB;EAClB,mBAAmB;EACnB,0CAA0C;EAC1C,eAAe,EAAA;;AAGjB;;EAEE,gBAAgB;EAChB,gBAAgB,EAAA;;AAGlB;EACE,WAAW;EACX,WAAW;EACX,gBAAgB;EAChB,kBAAkB,EAAA;;AAEpB;EACE,WAAW;EACX,kBAAkB,EAAA;;AAEpB;EACE,WAAW;EACX,gBAAgB;EAChB,eAAe;EACf,eAAe;EACf,kBAAkB,EAAA;;AAEpB;EACE,WAAW;EACX,4BAA4B;EAC5B,eAAe;EACf,iBAAiB;EACjB,qBAAqB;EACrB,gBAAgB;EAChB,aAAa,EAAA;;AAEf;EACE,iBAAiB;EACjB,qBAAqB;EACrB,WAAW,EAAA;;AAEb;EACE,WAAW;EACX,YAAY;EACZ,kBAAkB;EAClB,qBAAqB;EACrB,kBAAkB;EAClB,WAAW;EACX,SAAS,EAAA;EAPX;IAUI,cAAc;IACd,kBAAkB;IAClB,gCAAgC;IAChC,WAAW;IACX,eAAe;IACf,SAAS;IACT,QAAQ,EAAA;;AAIZ;;;;EAIE,eAAe;EACf,WAAW,EAAA;;AAGb;;EAEE,iBAAiB,EAAA;;AAGnB;;EAEE,kBAAkB,EAAA;;AAGpB;;EAEE,iBAAiB;EACjB,kBAAkB,EAAA","sourcesContent":[".rnc__notification-container--top-center,\r\n.rnc__notification-container--top-left,\r\n.rnc__notification-container--top-right,\r\n.rnc__notification-container--bottom-center,\r\n.rnc__notification-container--bottom-left,\r\n.rnc__notification-container--bottom-right,\r\n.rnc__notification-container--center,\r\n.rnc__notification-container--top-full,\r\n.rnc__notification-container--bottom-full {\r\n  min-width: 325px;\r\n  position: absolute;\r\n  pointer-events: all;\r\n}\r\n\r\n.rnc__notification-container--center,\r\n.rnc__notification-container--top-center,\r\n.rnc__notification-container--bottom-center {\r\n  display: flex;\r\n  justify-content: center;\r\n  align-items: center;\r\n  flex-direction: column;\r\n  left: calc(50% - 175px);\r\n}\r\n\r\n.rnc__notification-container--center,\r\n.rnc__notification-container--top-center,\r\n.rnc__notification-container--bottom-center {\r\n  max-width: 350px;\r\n}\r\n\r\n.rnc__notification-container--center {\r\n  top: 20px;\r\n  height: 100%;\r\n  pointer-events: none;\r\n}\r\n\r\n.rnc__notification-container--top-full,\r\n.rnc__notification-container--bottom-full {\r\n  width: 100%;\r\n  min-width: 100%;\r\n}\r\n\r\n.rnc__notification-container--bottom-full {\r\n  bottom: 0;\r\n}\r\n\r\n.rnc__util--flex-center {\r\n  min-width: 325px;\r\n  display: flex;\r\n  justify-content: center;\r\n  align-items: center;\r\n  flex-direction: column;\r\n  pointer-events: all;\r\n}\r\n\r\n.rnc__notification-container--top-center {\r\n  top: 20px;\r\n}\r\n.rnc__notification-container--bottom-center {\r\n  bottom: 20px;\r\n}\r\n\r\n.rnc__notification-container--top-left {\r\n  left: 20px;\r\n  top: 20px;\r\n}\r\n\r\n.rnc__notification-container--top-right {\r\n  right: 20px;\r\n  top: 20px;\r\n}\r\n\r\n.rnc__notification-container--bottom-left {\r\n  left: 20px;\r\n  bottom: 20px;\r\n}\r\n\r\n.rnc__notification-container--bottom-right {\r\n  bottom: 20px;\r\n  right: 20px;\r\n}\r\n\r\n.rnc__notification-container--mobile-top,\r\n.rnc__notification-container--mobile-bottom {\r\n  pointer-events: all;\r\n  position: absolute;\r\n}\r\n\r\n.rnc__notification-container--mobile-top {\r\n  right: 20px;\r\n  left: 20px;\r\n  top: 20px;\r\n}\r\n\r\n.rnc__notification-container--mobile-bottom {\r\n  right: 20px;\r\n  left: 20px;\r\n  bottom: 20px;\r\n  margin-bottom: -15px;\r\n}\r\n","@import \"_variables.scss\";\r\n\r\n.rnc__notification-item--default {\r\n  background-color: $default;\r\n  border-left: 8px solid $default_dark;\r\n\r\n  .rnc__notification-timer {\r\n    background-color: $default_timer;\r\n  }\r\n  .rnc__notification-timer-filler {\r\n    background-color: $default_timer_filler;\r\n  }\r\n  .rnc__notification-close-mark {\r\n    background-color: $default;\r\n  }\r\n}\r\n\r\n.rnc__notification-item--success {\r\n  background-color: $success;\r\n  border-left: 8px solid $success_dark;\r\n\r\n  .rnc__notification-timer {\r\n    background-color: $success_timer;\r\n  }\r\n  .rnc__notification-timer-filler {\r\n    background-color: $success_timer_filler;\r\n  }\r\n  .rnc__notification-close-mark {\r\n    background-color: $success;\r\n  }\r\n}\r\n\r\n.rnc__notification-item--danger {\r\n  background-color: $danger;\r\n  border-left: 8px solid $danger_dark;\r\n\r\n  .rnc__notification-timer {\r\n    background-color: $danger_timer;\r\n  }\r\n  .rnc__notification-timer-filler {\r\n    background-color: $danger_timer_filler;\r\n  }\r\n  .rnc__notification-close-mark {\r\n    background-color: $danger;\r\n  }\r\n}\r\n\r\n.rnc__notification-item--info {\r\n  background-color: $info;\r\n  border-left: 8px solid $info_dark;\r\n\r\n  .rnc__notification-timer {\r\n    background-color: $info_timer;\r\n  }\r\n  .rnc__notification-timer-filler {\r\n    background-color: $info_timer_filler;\r\n  }\r\n  .rnc__notification-close-mark {\r\n    background-color: $info;\r\n  }\r\n}\r\n\r\n.rnc__notification-item--warning {\r\n  background-color: $warning;\r\n  border-left: 8px solid $warning_dark;\r\n\r\n  .rnc__notification-timer {\r\n    background-color: $warning_timer;\r\n  }\r\n  .rnc__notification-timer-filler {\r\n    background-color: $warning_timer_filler;\r\n  }\r\n  .rnc__notification-close-mark {\r\n    background-color: $warning;\r\n  }\r\n}\r\n\r\n.rnc__notification-item--awesome {\r\n  background-color: $awesome;\r\n  border-left: 8px solid $awesome_dark;\r\n\r\n  .rnc__notification-timer {\r\n    background-color: $awesome_timer;\r\n  }\r\n  .rnc__notification-timer-filler {\r\n    background-color: $awesome_timer_filler;\r\n  }\r\n  .rnc__notification-close-mark {\r\n    background-color: $awesome;\r\n  }\r\n}","$default: #007bff !default;\r\n$default_dark: #0562c7 !default;\r\n\r\n$success: #28a745 !default;\r\n$success_dark: #1f8838 !default;\r\n\r\n$danger: #dc3545 !default;\r\n$danger_dark: #bd1120 !default;\r\n\r\n$info: #17a2b8 !default;\r\n$info_dark: #138b9e !default;\r\n\r\n$warning: #eab000 !default;\r\n$warning_dark: #ce9c09 !default;\r\n\r\n$awesome: #685dc3 !default;\r\n$awesome_dark: #4c3fb1 !default;\r\n\r\n$default_timer: #007bff !default;\r\n$default_timer_filler: #fff !default;\r\n\r\n$success_timer: #28a745 !default;\r\n$success_timer_filler: #fff !default;\r\n\r\n$danger_timer: #dc3545 !default;\r\n$danger_timer_filler: #fff !default;\r\n\r\n$info_timer: #17a2b8 !default;\r\n$info_timer_filler: #fff !default;\r\n\r\n$warning_timer: #eab000 !default;\r\n$warning_timer_filler: #fff !default;\r\n\r\n$awesome_timer: #685dc3 !default;\r\n$awesome_timer_filler: #fff !default;\r\n","@import \"./_containers.scss\";\r\n@import \"./_types.scss\";\r\n\r\n@keyframes timer {\r\n  0% { width: 100%; }\r\n  100% { width: 0%; }\r\n}\r\n\r\n.rnc__base {\r\n  position: fixed;\r\n  z-index: 9000;\r\n  pointer-events: none;\r\n  width: 100%;\r\n  height: 100%;\r\n}\r\n\r\n.rnc__notification-item {\r\n  display: flex;\r\n  position: relative;\r\n  border-radius: 3px;\r\n  margin-bottom: 15px;\r\n  box-shadow: 1px 3px 4px rgba(0, 0, 0, 0.2);\r\n  cursor: pointer;\r\n}\r\n\r\n.rnc__notification-container--top-full .rnc__notification-item,\r\n.rnc__notification-container--bottom-full .rnc__notification-item {\r\n  margin-bottom: 0;\r\n  border-radius: 0;\r\n}\r\n\r\n.rnc__notification-timer {\r\n  width: 100%;\r\n  height: 3px;\r\n  margin-top: 10px;\r\n  border-radius: 5px;\r\n}\r\n.rnc__notification-timer-filler {\r\n  height: 3px;\r\n  border-radius: 5px;\r\n}\r\n.rnc__notification-title {\r\n  color: #fff;\r\n  font-weight: 700;\r\n  font-size: 14px;\r\n  margin-top: 5px;\r\n  margin-bottom: 5px;\r\n}\r\n.rnc__notification-message {\r\n  color: #fff;\r\n  max-width: calc(100% - 15px);\r\n  font-size: 14px;\r\n  line-height: 150%;\r\n  word-wrap: break-word;\r\n  margin-bottom: 0;\r\n  margin-top: 0;\r\n}\r\n.rnc__notification-content {\r\n  padding: 8px 15px;\r\n  display: inline-block;\r\n  width: 100%;\r\n}\r\n.rnc__notification-close-mark {\r\n  width: 18px;\r\n  height: 18px;\r\n  border-radius: 50%;\r\n  display: inline-block;\r\n  position: absolute;\r\n  right: 10px;\r\n  top: 10px;\r\n\r\n  &::after {\r\n    content: '\\D7';\r\n    position: absolute;\r\n    transform: translate(-50%, -50%);\r\n    color: #fff;\r\n    font-size: 12px;\r\n    left: 50%;\r\n    top: 50%;\r\n  }\r\n}\r\n\r\n.rnc__notification-container--mobile-top .rnc__notification-item,\r\n.rnc__notification-container--mobile-bottom .rnc__notification-item,\r\n.rnc__notification-container--mobile-top .notification,\r\n.rnc__notification-container--mobile-bottom .notification {\r\n  max-width: 100%;\r\n  width: 100%;\r\n}\r\n\r\n.rnc__notification-container--top-right .notification,\r\n.rnc__notification-container--bottom-right .notification {\r\n  margin-left: auto;\r\n}\r\n\r\n.rnc__notification-container--top-left .notification,\r\n.rnc__notification-container--bottom-left .notification {\r\n  margin-right: auto;\r\n}\r\n\r\n.rnc__notification-container--mobile-top .notification,\r\n.rnc__notification-container--mobile-bottom .notification {\r\n  margin-left: auto;\r\n  margin-right: auto;\r\n}"],"sourceRoot":""}]);
// Exports
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (___CSS_LOADER_EXPORT___);


/***/ }),

/***/ "./node_modules/css-loader/dist/runtime/api.js":
/*!*****************************************************!*\
  !*** ./node_modules/css-loader/dist/runtime/api.js ***!
  \*****************************************************/
/***/ ((module) => {



/*
  MIT License http://www.opensource.org/licenses/mit-license.php
  Author Tobias Koppers @sokra
*/
module.exports = function (cssWithMappingToString) {
  var list = []; // return the list of modules as css string

  list.toString = function toString() {
    return this.map(function (item) {
      var content = "";
      var needLayer = typeof item[5] !== "undefined";

      if (item[4]) {
        content += "@supports (".concat(item[4], ") {");
      }

      if (item[2]) {
        content += "@media ".concat(item[2], " {");
      }

      if (needLayer) {
        content += "@layer".concat(item[5].length > 0 ? " ".concat(item[5]) : "", " {");
      }

      content += cssWithMappingToString(item);

      if (needLayer) {
        content += "}";
      }

      if (item[2]) {
        content += "}";
      }

      if (item[4]) {
        content += "}";
      }

      return content;
    }).join("");
  }; // import a list of modules into the list


  list.i = function i(modules, media, dedupe, supports, layer) {
    if (typeof modules === "string") {
      modules = [[null, modules, undefined]];
    }

    var alreadyImportedModules = {};

    if (dedupe) {
      for (var k = 0; k < this.length; k++) {
        var id = this[k][0];

        if (id != null) {
          alreadyImportedModules[id] = true;
        }
      }
    }

    for (var _k = 0; _k < modules.length; _k++) {
      var item = [].concat(modules[_k]);

      if (dedupe && alreadyImportedModules[item[0]]) {
        continue;
      }

      if (typeof layer !== "undefined") {
        if (typeof item[5] === "undefined") {
          item[5] = layer;
        } else {
          item[1] = "@layer".concat(item[5].length > 0 ? " ".concat(item[5]) : "", " {").concat(item[1], "}");
          item[5] = layer;
        }
      }

      if (media) {
        if (!item[2]) {
          item[2] = media;
        } else {
          item[1] = "@media ".concat(item[2], " {").concat(item[1], "}");
          item[2] = media;
        }
      }

      if (supports) {
        if (!item[4]) {
          item[4] = "".concat(supports);
        } else {
          item[1] = "@supports (".concat(item[4], ") {").concat(item[1], "}");
          item[4] = supports;
        }
      }

      list.push(item);
    }
  };

  return list;
};

/***/ }),

/***/ "./node_modules/css-loader/dist/runtime/sourceMaps.js":
/*!************************************************************!*\
  !*** ./node_modules/css-loader/dist/runtime/sourceMaps.js ***!
  \************************************************************/
/***/ ((module) => {



module.exports = function (item) {
  var content = item[1];
  var cssMapping = item[3];

  if (!cssMapping) {
    return content;
  }

  if (typeof btoa === "function") {
    var base64 = btoa(unescape(encodeURIComponent(JSON.stringify(cssMapping))));
    var data = "sourceMappingURL=data:application/json;charset=utf-8;base64,".concat(base64);
    var sourceMapping = "/*# ".concat(data, " */");
    var sourceURLs = cssMapping.sources.map(function (source) {
      return "/*# sourceURL=".concat(cssMapping.sourceRoot || "").concat(source, " */");
    });
    return [content].concat(sourceURLs).concat([sourceMapping]).join("\n");
  }

  return [content].join("\n");
};

/***/ }),

/***/ "react":
/*!**************************************************************************************!*\
  !*** external {"commonjs":"react","commonjs2":"react","amd":"react","root":"React"} ***!
  \**************************************************************************************/
/***/ ((module) => {

module.exports = require("react");

/***/ })

/******/ 	});
/************************************************************************/
/******/ 	// The module cache
/******/ 	var __webpack_module_cache__ = {};
/******/ 	
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/ 		// Check if module is in cache
/******/ 		var cachedModule = __webpack_module_cache__[moduleId];
/******/ 		if (cachedModule !== undefined) {
/******/ 			return cachedModule.exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = __webpack_module_cache__[moduleId] = {
/******/ 			id: moduleId,
/******/ 			// no module.loaded needed
/******/ 			exports: {}
/******/ 		};
/******/ 	
/******/ 		// Execute the module function
/******/ 		__webpack_modules__[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/ 	
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/ 	
/************************************************************************/
/******/ 	/* webpack/runtime/compat get default export */
/******/ 	(() => {
/******/ 		// getDefaultExport function for compatibility with non-harmony modules
/******/ 		__webpack_require__.n = (module) => {
/******/ 			var getter = module && module.__esModule ?
/******/ 				() => (module['default']) :
/******/ 				() => (module);
/******/ 			__webpack_require__.d(getter, { a: getter });
/******/ 			return getter;
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/define property getters */
/******/ 	(() => {
/******/ 		// define getter functions for harmony exports
/******/ 		__webpack_require__.d = (exports, definition) => {
/******/ 			for(var key in definition) {
/******/ 				if(__webpack_require__.o(definition, key) && !__webpack_require__.o(exports, key)) {
/******/ 					Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 				}
/******/ 			}
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/hasOwnProperty shorthand */
/******/ 	(() => {
/******/ 		__webpack_require__.o = (obj, prop) => (Object.prototype.hasOwnProperty.call(obj, prop))
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/make namespace object */
/******/ 	(() => {
/******/ 		// define __esModule on exports
/******/ 		__webpack_require__.r = (exports) => {
/******/ 			if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 				Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 			}
/******/ 			Object.defineProperty(exports, '__esModule', { value: true });
/******/ 		};
/******/ 	})();
/******/ 	
/************************************************************************/
/******/ 	
/******/ 	// startup
/******/ 	// Load entry module and return exports
/******/ 	// This entry module is referenced by other modules so it can't be inlined
/******/ 	var __webpack_exports__ = __webpack_require__("./src/index.ts");
/******/ 	module.exports.ReactNotifications = __webpack_exports__;
/******/ 	
/******/ })()
;
//# sourceMappingURL=react-notifications.dev.js.map